@@ -1,17 +1,22 @@
 use strict;
 use warnings;
 package Log::Dispatch::File::Stamped;
+{
+  $Log::Dispatch::File::Stamped::VERSION = '0.12';
+}
+# git description: v0.11-3-gca8cbec
+
+BEGIN {
+  $Log::Dispatch::File::Stamped::AUTHORITY = 'cpan:ETHER';
+}
+# ABSTRACT: Logging to date/time stamped files
 
 use File::Basename        qw(fileparse);
 use File::Spec::Functions qw(catfile);
 use POSIX                 qw(strftime);
 
-use vars qw(@ISA $VERSION);
 use Log::Dispatch::File 2.38;
-@ISA = qw(Log::Dispatch::File);
-
-$VERSION = '0.11';      # for PAUSE
-$VERSION = eval $VERSION;   # the real version (a string literal)
+use parent 'Log::Dispatch::File';
 
 use Params::Validate qw(validate SCALAR);
 Params::Validate::validation_options( allow_extra => 1 );
@@ -80,11 +85,18 @@ sub log_message
 }
 
 1;
+
 __END__
 
+=pod
+
 =head1 NAME
 
-Log::Dispatch::File::Stamped - Logging to date/time stamped files (UNAUTHORIZED RELEASE)
+Log::Dispatch::File::Stamped - Logging to date/time stamped files
+
+=head1 VERSION
+
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -142,6 +154,8 @@ shouldn't be called directly but should be called through the
 
 =head1 EXAMPLES
 
+=for stopwords txt
+
 Assuming the current date and time is:
 
   % perl -e 'print scalar localtime'
@@ -168,24 +182,35 @@ This will log to file 'logfile-0813.txt'.
 
 L<Log::Dispatch::File>, L<POSIX>.
 
-=head1 AUTHOR
-
-Eric Cholet <cholet@logilune.com>
-
-=head1 COPYRIGHT
-
-The Log::Dispatch::File::Stamped is free software. You may
-distribute it under the terms of either the GNU General
-Public License or the Artistic License, as specified in the
-Perl README file.
-
 =head1 ACKNOWLEDGEMENTS
 
+=for stopwords Rolsky
+
 Dave Rolsky, author of the Log::Dispatch suite and many other
 fine modules on CPAN.
 
 This module was rewritten to respect all present (and future) options to
 L<Log::Dispatch::File> by Karen Etheridge, <ether@cpan.org>.
 
-=cut
+=head1 AUTHORS
 
+=over 4
+
+=item *
+
+Eric Cholet <cholet@logilune.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Karen Etheridge.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
